

/* 
 *  Licensed Materials - Property of IBM
 *  Use Restricted Material of IBM - please refer to the "Samples Code" terms and conditions in the IBM International Program License Agreement (IPLA).
 *  IBM Rational Test RealTime
 *  (c) Copyright IBM Corp. 2003-2007 All Rights Reserved.
 *
 *  US Governement Users Restricted Rights - Use, duplication or
 *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */



package baseStation;

import java.net.*;
import java.io.*;

public class UmtsConnection implements Runnable
{
	private Socket _socket;
	private int _num;
	private NetworkLoadMonitor _netLoadMonitor;
	private int _state;
	private final int _notConnected=0;
	private final int _connected=1;
	private final int _busy=2;
	
	public void setNetworkLoadMonitor(NetworkLoadMonitor netLoadMonitor)
	{
		_netLoadMonitor=netLoadMonitor;
	}

	public UmtsConnection(int num)
	{
		_num=num;
	}

	public void setSocket(Socket socket)
	{
		_socket=socket;
	}
	
	public void run()
	{
		_netLoadMonitor.oneCnxStarted();
		try 
		{	
			UmtsReader input = new UmtsReader(_socket.getInputStream());
			UmtsWriter output = new UmtsWriter(new OutputStreamWriter(_socket.getOutputStream()));
			// process received data 
			_state=_notConnected;
	    	while(true) 
	    	{
				UmtsMsg message = input.readMsg();
				switch (_state)
				{
					case _notConnected:
					{
						if (message.isCmdConnectionRequest())
						{
							message.setCommand(UmtsMsg.CNX_ACCEPTED);
							message.setBaseStationId(123);
							output.writeMsg(message);
							_state=_connected;
						}
						else
						{
							message.setCommand(UmtsMsg.UNREACHABLE);
							message.setBaseStationId(123);
							output.writeMsg(message);
						}				
					 break;
					}
					case _connected:
					{
						if (message.isCmdCall())
						{
						// Tutorial info
						// dial the 5550001 phone number to cover
						// the following statement block
							if (message.getPhoneNumber().equals("5550001"))
							{
								message.setCommand(UmtsMsg.ACCEPTED);
								output.writeMsg(message);
								_state=_busy;
							}
							else
							{
								message.setCommand(UmtsMsg.BUSY);
								output.writeMsg(message);
							}
						}
						else
						{
							message.setCommand(UmtsMsg.UNREACHABLE);
							message.setBaseStationId(123);
							output.writeMsg(message);
						}				
					 break;
					}
					case _busy:
					{
							message.setCommand(UmtsMsg.BUSY);
							output.writeMsg(message);
							_state=_busy;
					 break;
					}
				}
	    	}
		}
		catch (Exception e) 
		{
	    	System.out.println(e);
    		// connection closed by client
        	System.out.println("Connection #"+_num+" closed by client");
   		_netLoadMonitor.oneCnxTerminated();
	    }
	}
}
