

/* 
 *  Licensed Materials - Property of IBM
 *  Use Restricted Material of IBM - please refer to the "Samples Code" terms and conditions in the IBM International Program License Agreement (IPLA).
 *  IBM Rational Test RealTime
 *  (c) Copyright IBM Corp. 2003-2007 All Rights Reserved.
 *
 *  US Governement Users Restricted Rights - Use, duplication or
 *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */



package baseStation;

import java.io.*;

public class UmtsReader extends InputStreamReader
{
	public UmtsReader(InputStream input)
	{
		super(input);
	}
	public UmtsMsg readMsg() throws UmtsException
	{
		UmtsMsg msg=new UmtsMsg();
		
		msg.setCommand(readString());
		if (msg.isCmdCall() ||
			msg.isCmdAccepted() ||
			msg.isCmdBusy() ||
			msg.isCmdUnreachable() ||
			msg.isCmdEndOfCall())
	    {
	    	msg.setPhoneNumber(readString());
    	}
    	msg.setSimCardId(readInteger());
    	if (!msg.isCmdConnectionRequest()) 
  	    {
  	    	msg.setBaseStationId(readInteger());
		}
		return (msg);
	}
	
	private String readString() throws UmtsException
	{
		Character length;
		char nextChar;
		int len;
		StringBuffer result = new StringBuffer("");
		
		try
		{
			nextChar=(char) super.read();
			if (nextChar!='S') throw new UmtsException("UmtsReader: not a string");
			length=new Character((char) super.read());
			if (!Character.isDigit(length.charValue())) throw new UmtsException("UmtsReader: bad string length");
			len=Integer.parseInt(length.toString());
			while (len>0)
			{
				nextChar=(char) super.read();
				result.append(nextChar);
				len--;
			}
			return (result.toString());
		}
		catch (IOException e)
		{
			throw new UmtsException("UmtsReader: "+e.toString());
		}
	}
	
	private int readInteger() throws UmtsException
	{
		Character length;
		char nextChar;
		int len;
		StringBuffer result = new StringBuffer("");
		
		try
		{
			nextChar=(char) super.read();
			if (nextChar!='I') throw new UmtsException("UmtsReader: not an integer");
			length=new Character((char) super.read());
			if (!Character.isDigit(length.charValue())) throw new UmtsException("UmtsReader: bad integer length");
			len=Integer.parseInt(length.toString());
			while (len>0)
			{
				nextChar=(char) super.read();
				result.append(nextChar);
				len--;
			}
			result.reverse();
			return (Integer.parseInt(result.toString()));
		}
		catch (IOException e)
		{
			throw new UmtsException("UmtsReader: "+e.toString());
		}
	}
}
